.. _user_guide:

****************
SciPy User Guide
****************

.. sectionauthor:: Travis E. Oliphant

.. raw:: latex

   \addtocontents{toc}{\protect\setcounter{tocdepth}{2}}

.. toctree::
   :maxdepth: 1

   general
   special
   integrate
   optimize
   interpolate
   fft
   signal
   linalg
   arpack
   csgraph
   spatial
   stats
   ndimage
   io

.. raw:: latex

   \addtocontents{toc}{\protect\setcounter{tocdepth}{1}}
